@@ -33,7 +33,7 @@
 #include "gtr-tab.h"
 #include "gtr-plugins-engine.h"
 #include "gtr-po.h"
-#include "gtr-prefs-manager-app.h"
+#include "gtr-settings.h"
 #include "gtr-statusbar.h"
 #include "gtr-utils.h"
 #include "gtr-window.h"
@@ -78,6 +78,9 @@ G_DEFINE_TYPE (GtrWindow, gtr_window, GTK_TYPE_WINDOW)
 
 struct _GtrWindowPrivate
 {
+  GSettings *ui_settings;
+  GSettings *state_settings;
+
   GtkWidget *main_box;
 
   GtkWidget *menubar;
@@ -110,7 +113,8 @@ struct _GtrWindowPrivate
   GtrProfileManager *prof_manager;
   GtkWidget *profile_combo;
 
-  gboolean destroy_has_run : 1;
+  guint destroy_has_run : 1;
+  guint dispose_has_run : 1;
 };
 
 enum
@@ -192,9 +196,6 @@ static const GtkActionEntry entries[] = {
    G_CALLBACK (gtr_actions_edit_clear)},
   {"EditHeader", GTK_STOCK_PROPERTIES, N_("_Header..."), NULL, NULL,
    G_CALLBACK (gtr_actions_edit_header)},
-  {"EditComment", GTK_STOCK_INDEX, N_("C_omment..."), NULL,
-   N_("Edit message comment"),
-   G_CALLBACK (gtr_edit_message_comment)},
   {"EditMessage2Trans", NULL, N_("Copy _Message to Translation"),
    "<control>space",
    N_("Copy original message contents to the translation field"),
@@ -210,9 +211,6 @@ static const GtkActionEntry entries[] = {
   {"ViewContext", NULL, N_("_Context"), "<control>J",
    N_("Show the Context panel"),
    G_CALLBACK (gtr_actions_view_context)},
-  {"ViewTranslationMemory", NULL, N_("_Translation Memory"), "<control>K",
-   N_("Show the Translation Memory panel"),
-   G_CALLBACK (gtr_actions_view_translation_memory)},
 
   /* Go menu */
   {"GoPrevious", GTK_STOCK_GO_BACK, N_("_Previous Message"),
@@ -838,7 +836,7 @@ update_documents_list_menu (GtrWindow * window)
        * get the same accel.
        */
       action_name = g_strdup_printf ("Tab_%d", i);
-      tab_name = gtr_tab_get_name (GTR_TAB (tab));
+      tab_name = _gtr_tab_get_name (GTR_TAB (tab));
       name = gtr_utils_escape_underscores (tab_name, -1);
       tip = get_menu_tip_for_tab (GTR_TAB (tab));
 
@@ -973,7 +971,7 @@ set_window_title (GtrWindow * window, gboolean with_path)
 
 static void
 notebook_switch_page (GtkNotebook * nb,
-                      GtkNotebookPage * page,
+                      GtkWidget * page,
                       gint page_num, GtrWindow * window)
 {
   GtrTab *tab;
@@ -1338,15 +1336,17 @@ gtr_window_cmd_edit_toolbar (GtkAction * action, GtrWindow * window)
 {
   GtkWidget *dialog;
   GtkWidget *editor;
+  GtkWidget *content_area;
 
   dialog = gtk_dialog_new_with_buttons (_("Toolbar Editor"),
                                         GTK_WINDOW (window),
                                         GTK_DIALOG_DESTROY_WITH_PARENT,
                                         GTK_STOCK_CLOSE,
                                         GTK_RESPONSE_CLOSE, NULL);
+  content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
   gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+  gtk_box_set_spacing (GTK_BOX (content_area), 2);
   gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
   gtk_window_set_default_size (GTK_WINDOW (dialog), 500, 400);
 
@@ -1357,7 +1357,7 @@ gtr_window_cmd_edit_toolbar (GtkAction * action, GtrWindow * window)
   gtk_container_set_border_width (GTK_CONTAINER (editor), 5);
   gtk_box_set_spacing (GTK_BOX (EGG_TOOLBAR_EDITOR (editor)), 5);
 
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), editor);
+  gtk_container_add (GTK_CONTAINER (content_area), editor);
 
   egg_editable_toolbar_set_edit_mode
     (EGG_EDITABLE_TOOLBAR (window->priv->toolbar), TRUE);
@@ -1487,6 +1487,8 @@ create_statusbar (GtrWindow *window,
   gtk_widget_show (window->priv->statusbar);
 
   window->priv->profile_combo = gtr_status_combo_box_new (_("Profile"));
+  gtk_widget_set_tooltip_text (window->priv->profile_combo,
+                               _("Profile for the active document"));
   gtk_box_pack_start (GTK_BOX (window->priv->statusbar),
                       window->priv->profile_combo, FALSE, TRUE, 0);
 
@@ -1740,7 +1742,9 @@ gtr_window_draw (GtrWindow * window)
   priv->layout_manager = gdl_dock_layout_new (GDL_DOCK (priv->dock));
   g_object_set (priv->layout_manager->master,
                 "switcher-style",
-                gtr_prefs_manager_get_pane_switcher_style (), NULL);
+                g_settings_get_enum (priv->ui_settings,
+                                     GTR_SETTINGS_PANEL_SWITCHER_STYLE),
+                NULL);
   g_signal_connect (priv->layout_manager,
                     "notify::dirty",
                     G_CALLBACK (on_layout_dirty_notify), window);
@@ -1776,7 +1780,11 @@ gtr_window_init (GtrWindow * window)
 
   window->priv = GTR_WINDOW_GET_PRIVATE (window);
 
+  window->priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
+  window->priv->state_settings = g_settings_new ("org.gnome.gtranslator.state.window");
+
   window->priv->destroy_has_run = FALSE;
+  window->priv->dispose_has_run = FALSE;
 
   /* Profile manager */
   window->priv->prof_manager = gtr_profile_manager_get_default ();
@@ -1846,6 +1854,25 @@ gtr_window_init (GtrWindow * window)
   g_free (filename);
 }
 
+static void
+save_panes_state (GtrWindow * window)
+{
+  gchar *filename;
+  gchar *config_folder;
+
+  g_settings_set (window->priv->state_settings, GTR_SETTINGS_WINDOW_SIZE, "(ii)",
+                  window->priv->width, window->priv->height);
+  g_settings_set_int (window->priv->state_settings, GTR_SETTINGS_WINDOW_STATE,
+                      window->priv->window_state);
+
+  config_folder = gtr_dirs_get_user_config_dir ();
+  filename = g_build_filename (config_folder, "gtr-layout.xml", NULL);
+  g_free (config_folder);
+
+  gtr_window_layout_save (window, filename, NULL);
+  g_free (filename);
+}
+
 static void
 gtr_window_dispose (GObject * object)
 {
@@ -1854,6 +1881,24 @@ gtr_window_dispose (GObject * object)
 
   DEBUG_PRINT ("window dispose");
 
+  if (!priv->dispose_has_run)
+    {
+      save_panes_state (window);
+      priv->dispose_has_run = TRUE;
+    }
+
+  if (priv->ui_settings)
+    {
+      g_object_unref (priv->ui_settings);
+      priv->ui_settings = NULL;
+    }
+
+  if (priv->state_settings)
+    {
+      g_object_unref (priv->state_settings);
+      priv->state_settings = NULL;
+    }
+
   if (priv->ui_manager)
     {
       g_object_unref (priv->ui_manager);
@@ -1885,27 +1930,6 @@ gtr_window_finalize (GObject * object)
   G_OBJECT_CLASS (gtr_window_parent_class)->finalize (object);
 }
 
-static void
-save_panes_state (GtrWindow * window)
-{
-  gchar *filename;
-  gchar *config_folder;
-
-  if (gtr_prefs_manager_window_size_can_set ())
-    gtr_prefs_manager_set_window_size (window->priv->width,
-                                       window->priv->height);
-
-  if (gtr_prefs_manager_window_state_can_set ())
-    gtr_prefs_manager_set_window_state (window->priv->window_state);
-
-  config_folder = gtr_dirs_get_user_config_dir ();
-  filename = g_build_filename (config_folder, "gtr-layout.xml", NULL);
-  g_free (config_folder);
-
-  gtr_window_layout_save (window, filename, NULL);
-  g_free (filename);
-}
-
 static void
 gtr_window_destroy (GtkObject * object)
 {
@@ -1917,8 +1941,6 @@ gtr_window_destroy (GtkObject * object)
 
   if (!window->priv->destroy_has_run)
     {
-      save_panes_state (window);
-
       if (window->priv->widgets)
         {
           g_hash_table_destroy (window->priv->widgets);
